# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS & White Box as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "wbel"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# Perl::Critic not available prior to FC-5 and Perl 5.8.8
%global have_perl_critic %(perl -e 'print (($^V and $^V ge 5.8.8) ? 1 : 0);')

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'printf "%d\\n", $Test::More::VERSION < 0.88 ? 1 : 0;' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if %(perl -e 'print (($^V and $^V ge 5.10.0) ? 1 : 0);')
%global speller hunspell
%else
%global speller aspell
%endif

Name:		perl-Exception-Base
Version:	0.2401
Release:	3.%{__distinit}%{__distvers}
Summary:	Lightweight exceptions
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Exception-Base/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/Exception-Base-%{version}.tar.gz
Source1:	C0B10A5B.pub
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Test::Unit::Lite)
# Release test requirements
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
%if %{have_perl_critic}
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling)
%if %(perl -e 'print (($] >= 5.008001) ? 1 : 0)')
BuildRequires:	%{speller}-en
%else
BuildRequires:	%{speller}-en-gb
%endif
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
This class implements a fully OO exception mechanism similar to
Exception::Class or Class::Throwable. It provides a simple interface
allowing programmers to declare exception classes. These classes can be
thrown and caught. Each uncaught exception prints full stack trace if the
default verbosity is increased for debugging purposes.

%prep
%setup -q -c -n Exception-Base

# Copy up documentation for convenience with %%doc
cp -a Exception-Base-%{version}/{Changes,eg,Incompatibilities,LICENSE,README} .

# Drop exec bits from examples to avoid doc-file dependencies
chmod -c -x eg/*

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

%build
cd Exception-Base-%{version}
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make -C Exception-Base-%{version} pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd Exception-Base-%{version}

# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t | sed 's|xt/copyright.t||')"
# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"
# Don't run the Perl::Critic test if we don't have Test::Perl::Critic
%if !%{have_perl_critic}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"
%endif
# Don't run the spelling test as we need to add extra stopwords
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/pod_spell.t||')"
# Changes test needs tweaking if we don't have Test::More >= 0.88,
# but don't do it yet as it would cause the signature test to fail
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/check_changes.t||')"
%endif
make test TEST_FILES="$RELEASE_TESTS"
# Now try the Changes test if we didn't run it before
%if %{old_test_more}
sed -e 's|^use Test::CheckChanges;|use Test::More tests => 1;\n&|' xt/check_changes.t > xt/check_changes_compat.t
make test TEST_FILES=xt/check_changes_compat.t
%endif
# Fix the POD Spell test and run it
(
	echo "'Unknown"
	echo "'is'"
	echo "'message'"
	echo "'s"
	echo "'value'"
	echo "10x"
	echo "15x"
	echo "exception'"
	echo "informations"
	echo "doesn"
	echo "shouldn"
) >> xt/pod_spellrc
make test TEST_FILES=xt/pod_spell.t

cd -

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes LICENSE Incompatibilities README eg/
%{perl_vendorlib}/Exception/
%{_mandir}/man3/Exception::Base.3pm*

%changelog
* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.2401-3
- Import from Fedora

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2401-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Oct 03 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.2401-1
- Update to 0.2401

* Sat May 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.24-3
- Mass rebuild with perl-5.12.0

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.24-2
- Mass rebuild with perl-5.12.0

* Sun Apr  4 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.24-1
- Update to 0.24
- Add perl(Test::Unit::Lite) to BuildRequires

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.21-4
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.21-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> - 0.21-1
- Initial RPM release
